@@ -19,13 +19,12 @@
 #' tadaa_pairwise_gh(ngo, deutsch, jahrgang)
 #' tadaa_pairwise_gh(ngo, deutsch, jahrgang, geschl)
 tadaa_pairwise_gh <- function(data, response, group1, group2 = NULL, print = "df") {
-
   response <- deparse(substitute(response))
-  group1   <- deparse(substitute(group1))
-  group2   <- deparse(substitute(group2))
+  group1 <- deparse(substitute(group1))
+  group2 <- deparse(substitute(group2))
 
   # Tests
-  tests      <- games_howell(data[[response]], data[[group1]])
+  tests <- games_howell(data[[response]], data[[group1]])
   tests$term <- group1
 
   # If second group is defined, we do interactions and stuff
@@ -35,7 +34,7 @@ tadaa_pairwise_gh <- function(data, response, group1, group2 = NULL, print = "df
     tests_int <- games_howell(data[[response]], data[["interaction"]])
     tests_int$term <- paste0(group1, ":", group2)
 
-    test_2      <- games_howell(data[[response]], data[[group2]])
+    test_2 <- games_howell(data[[response]], data[[group2]])
     test_2$term <- group2
 
     tests <- rbind(tests, test_2, tests_int)
@@ -43,8 +42,10 @@ tadaa_pairwise_gh <- function(data, response, group1, group2 = NULL, print = "df
 
   rownames(tests) <- NULL
 
-  tests <- tests[c("term", "comparison", "se", "t", "df",
-                   "conf_low", "conf_high", "adj.p.value")]
+  tests <- tests[c(
+    "term", "comparison", "se", "t", "df",
+    "conf_low", "conf_high", "adj.p.value"
+  )]
 
   if (print == "df") {
     return(tests)
@@ -52,7 +53,7 @@ tadaa_pairwise_gh <- function(data, response, group1, group2 = NULL, print = "df
     output <- pixiedust::dust(tests)
     output <- pixiedust::sprinkle(output, cols = "adj.p.value", fn = quote(tadaatoolbox::pval_string(value)))
     output <- pixiedust::sprinkle_colnames(output, adj.p.value = "p (adj.)")
-    #output <- pixiedust::sprinkle_table(output, cols = 1, caption = "", part = "head")
+    # output <- pixiedust::sprinkle_table(output, cols = 1, caption = "", part = "head")
   }
 
   if (!(print %in% c("df", "console", "html", "markdown"))) {
@@ -80,30 +81,29 @@ games_howell <- function(obs, grp) {
   # groups = number of groups in data
   # Mean = means of each group sample
   # std = variance of each group sample
-  n      <- tapply(obs, grp, length)
+  n <- tapply(obs, grp, length)
   groups <- length(tapply(obs, grp, length))
-  Mean   <- tapply(obs, grp, mean)
-  std    <- tapply(obs, grp, var)
+  Mean <- tapply(obs, grp, mean)
+  std <- tapply(obs, grp, var)
 
   statistics <- lapply(1:ncol(combs), function(x) {
+    mean.diff <- Mean[combs[2, x]] - Mean[combs[1, x]]
 
-    mean.diff <- Mean[combs[2,x]] - Mean[combs[1,x]]
-
-    #t-values
-    t <- abs(Mean[combs[1,x]] - Mean[combs[2,x]]) /
-         sqrt((std[combs[1,x]] / n[combs[1,x]]) +
-                (std[combs[2,x]] / n[combs[2,x]]))
+    # t-values
+    t <- abs(Mean[combs[1, x]] - Mean[combs[2, x]]) /
+      sqrt((std[combs[1, x]] / n[combs[1, x]]) +
+        (std[combs[2, x]] / n[combs[2, x]]))
 
     # Degrees of Freedom
-    df <- (std[combs[1,x]] / n[combs[1,x]] + std[combs[2,x]] / n[combs[2,x]])^2 / # num df
-      ((std[combs[1,x]] / n[combs[1,x]])^2 / (n[combs[1,x]] - 1) + # Part 1 of denom df
-         (std[combs[2,x]] / n[combs[2,x]])^2 / (n[combs[2,x]] - 1)) # Part 2 of denom df
+    df <- (std[combs[1, x]] / n[combs[1, x]] + std[combs[2, x]] / n[combs[2, x]]) ^ 2 / # num df
+      ((std[combs[1, x]] / n[combs[1, x]]) ^ 2 / (n[combs[1, x]] - 1) + # Part 1 of denom df
+        (std[combs[2, x]] / n[combs[2, x]]) ^ 2 / (n[combs[2, x]] - 1)) # Part 2 of denom df
 
     # p-values
     p <- ptukey(t * sqrt(2), groups, df, lower.tail = FALSE)
 
     # Sigma standard error
-    se <- sqrt(0.5 * (std[combs[1,x]] / n[combs[1,x]] + std[combs[2,x]] / n[combs[2,x]]))
+    se <- sqrt(0.5 * (std[combs[1, x]] / n[combs[1, x]] + std[combs[2, x]] / n[combs[2, x]]))
 
     # Upper Confidence Limit
     upper.conf <- lapply(1:ncol(combs), function(x) {
@@ -116,7 +116,7 @@ games_howell <- function(obs, grp) {
     })[[1]]
 
     # Group Combinations
-    grp.comb <- paste(combs[1,x], ':', combs[2,x])
+    grp.comb <- paste(combs[1, x], ":", combs[2, x])
 
     # Collect all statistics into list
     stats <- list(grp.comb, mean.diff, se, t, df, p, lower.conf, upper.conf)
@@ -128,17 +128,24 @@ games_howell <- function(obs, grp) {
   })
 
   # Create dataframe from flattened list
-  results <- data.frame(matrix(unlist(stats.unlisted),
-                               nrow = length(stats.unlisted), byrow=TRUE))
+  results <- data.frame(matrix(
+    unlist(stats.unlisted),
+    nrow = length(stats.unlisted), byrow = TRUE
+  ))
 
   # Select columns set as factors that should be numeric and change with as.numeric
-  results[c(2, 3:ncol(results))] <- round(as.numeric(as.matrix(
-                                                     results[c(2, 3:ncol(results))])),
-                                    digits = 3)
+  results[c(2, 3:ncol(results))] <- round(
+    as.numeric(as.matrix(
+      results[c(2, 3:ncol(results))]
+    )),
+    digits = 3
+  )
 
   # Rename data frame columns
-  colnames(results) <- c('comparison', 'diff', 'se', 't', 'df',
-                         'adj.p.value', 'conf_low', 'conf_high')
+  colnames(results) <- c(
+    "comparison", "diff", "se", "t", "df",
+    "adj.p.value", "conf_low", "conf_high"
+  )
 
   results
 }
